CapSubCommand

Enum CapSubCommand 

pub enum CapSubCommand {
    LS,
    LIST,
    REQ,
    ACK,
    NAK,
    END,
    NEW,
    DEL,
}
A list of all of the subcommands for the capabilities extension.

Variants



LS

Requests a list of the server’s capabilities.



LIST

Requests a list of the server’s capabilities.



REQ

Requests specific capabilities blindly.



ACK

Acknowledges capabilities.



NAK

Does not acknowledge certain capabilities.



END

Ends the capability negotiation before registration.



NEW

Signals that new capabilities are now being offered.



DEL

Signasl that the specified capabilities are cancelled and no longer available.

Implementations

Source

impl CapSubCommand

pub fn to_str(&self) -> &str

Gets the string that corresponds to this subcommand.